aboutsummaryrefslogtreecommitdiffstats
path: root/widgets/misc/e-popup-action.h
diff options
context:
space:
mode:
authorMatthew Barnes <mbarnes@redhat.com>2009-11-13 10:27:40 +0800
committerMatthew Barnes <mbarnes@redhat.com>2009-11-14 00:26:43 +0800
commitc5e04ca04066ae2d92d3999626ef91d5d0606cab (patch)
tree4c4cc28faa947d29d9f6e575680549daf95ae753 /widgets/misc/e-popup-action.h
parentba89f0b2c4993c562a1bdb0f5ce90b654c3b68b5 (diff)
downloadgsoc2013-evolution-c5e04ca04066ae2d92d3999626ef91d5d0606cab.tar
gsoc2013-evolution-c5e04ca04066ae2d92d3999626ef91d5d0606cab.tar.gz
gsoc2013-evolution-c5e04ca04066ae2d92d3999626ef91d5d0606cab.tar.bz2
gsoc2013-evolution-c5e04ca04066ae2d92d3999626ef91d5d0606cab.tar.lz
gsoc2013-evolution-c5e04ca04066ae2d92d3999626ef91d5d0606cab.tar.xz
gsoc2013-evolution-c5e04ca04066ae2d92d3999626ef91d5d0606cab.tar.zst
gsoc2013-evolution-c5e04ca04066ae2d92d3999626ef91d5d0606cab.zip
EWebView popup menu enhancements.
Bumps the GtkHtml dependency to 3.29.2 for gtk_html_unselect_all().
Diffstat (limited to 'widgets/misc/e-popup-action.h')
-rw-r--r--widgets/misc/e-popup-action.h15
1 files changed, 6 insertions, 9 deletions
diff --git a/widgets/misc/e-popup-action.h b/widgets/misc/e-popup-action.h
index d19971f303..02469375d5 100644
--- a/widgets/misc/e-popup-action.h
+++ b/widgets/misc/e-popup-action.h
@@ -28,9 +28,9 @@
* To use:
*
* Create an array of EPopupActionEntry structs. Add the main menu actions
* that serve as "sources" for the popup actions to an action group first.
* Then pass the same action group and the EPopupActionEntry array to
* e_action_group_add_popup_actions() to add popup actions.
*/
#ifndef E_POPUP_ACTION_H
@@ -75,15 +75,12 @@ struct _EPopupActionClass {
struct _EPopupActionEntry {
const gchar *name;
- const gchar *label; /* optional: overrides the source action */
- const gchar *source; /* name of the source action */
+ const gchar *label; /* optional: overrides the related action */
+ const gchar *related; /* name of the related action */
};
GType e_popup_action_get_type (void);
-EPopupAction * e_popup_action_new (const gchar *name,
- const gchar *label,
- GtkAction *source);
-GtkAction * e_popup_action_get_source (EPopupAction *popup_action);
+EPopupAction * e_popup_action_new (const gchar *name);
void e_action_group_add_popup_actions
(GtkActionGroup *action_group,
@@ -28,9 +28,9 @@
*
* Create an array of EPopupActionEntry structs. Add the main menu actions
- * that serve as "sources" for the popup actions to an action group first.
- * Then pass the same action group and the EPopupActionEntry array to
- * e_action_group_add_popup_actions() to add popup actions.
+ * that serve as related actions for the popup actions to an action group
+ * first. Then pass the same action group and the EPopupActionEntry array
+ * to e_action_group_add_popup_actions() to add popup actions.
*/
#ifndef E_POPUP_ACTION_H